library(meta)
library(metafor)

#state anxiety
title_anxiety <- c("Shearer (2015)", "Wilson (1987)", "Crossman (2015)", "Banks (2018)")
TE <- c(-0.811, 0.0413, -1.245, -0.411)
seTE <- c(0.328, 0.209, 0.331, 0.27)


ni <- c(25, 46, 22, 29)
nc <- c(22, 46, 22, 27) 


anxiety <- metagen(TE,
                  seTE,
                  studlab = paste(title_anxiety),
                  comb.fixed = FALSE,
                  comb.random = TRUE,
                  method.tau = "DL",
                  hakn = TRUE,
                  prediction = FALSE,
                  sm = "SMD",
                  n.e = ni,
                  n.c = nc,
                  label.e = "N(i)",
                  label.c = "N(c)")
anxiety
forest(anxiety)

#Long-term stress
title_stress <- c("Ward-Griffin (2018) - RCT", "Banks (2018)", "Binfet (2017)")
TE <- c(-0.128, -0.411, -0.326)
seTE <- c(0.128, 0.27, 0.162)

ni <- c(122, 29, 84)
nc <- c(124, 27, 79)

stress <- metagen(TE,
                   seTE,
                   studlab = paste(title_stress),
                   comb.fixed = FALSE,
                   comb.random = TRUE,
                   method.tau = "DL",
                   hakn = TRUE,
                   prediction = FALSE,
                   sm = "SMD",
                   n.e = ni,
                   n.c = nc,
                   label.e = "N(i)",
                   label.c = "N(c)")
stress
forest(stress)

#positive affect
title_pa <- c("Ward-Griffin (2018) - RCT", "Crossman (2015)", "Banks (2018)")
TE <- c(-0.088, 0.564, -0.104)
seTE <- c(0.128, 0.308, 0.268)

ni <- c(122, 22, 29)
nc <- c(124, 22, 27)

pa <- metagen(TE,
                  seTE,
                  studlab = paste(title_pa),
                  comb.fixed = FALSE,
                  comb.random = TRUE,
                  method.tau = "DL",
                  hakn = TRUE,
                  prediction = FALSE,
                  sm = "SMD",
                  n.e = ni,
                  n.c = nc,
                  label.e = "N(i)",
                  label.c = "N(c)")
pa
forest(pa)

#negative affect
title_na <- c("Ward-Griffin (2018) - RCT", "Shearer (2015)", "Crossman (2015)", "Banks (2018)")
TE <- c(-0.081, -0.612, -1.391, -0.011)
seTE <- c(0.127, 0.322, 0.337, 0.267)

ni <- c(122, 25, 22, 29)
nc <- c(124, 22, 22, 27)

na <- metagen(TE,
              seTE,
              studlab = paste(title_na),
              comb.fixed = FALSE,
              comb.random = TRUE,
              method.tau = "DL",
              hakn = TRUE,
              prediction = FALSE,
              sm = "SMD", 
              n.e = ni,
              n.c = nc,
              label.e = "N(i)",
              label.c = "N(c)")
na
forest(na)

#BP
title_bp <- c("McDonald (2017) - systolic", "Wilson (1987) - systolic", 
              "Crump (2015) - Study I - systolic")

TE <- c(-2.501, 0.21, 0.841)
seTE <- c(0.389, 0.21, 0.402)

ni <- c(22, 46, 27)
nc <- c(26, 46, 27)

bp <- metagen(TE,
              seTE,
              studlab = paste(title_bp),
              comb.fixed = FALSE,
              comb.random = TRUE,
              method.tau = "DL",
              hakn = TRUE,
              prediction = FALSE,
              sm = "SMD", 
              n.e = ni,
              n.c = nc,
              label.e = "N(i)",
              label.c = "N(c)")
bp
forest(bp, overall= FALSE)

#overall funnel
yi <- c(-0.811, 0.0413, -1.245, -0.411, -0.128, -0.411, -0.326, -0.088, 0.564, -0.104, -0.081, -0.612, -1.391, -0.011, -2.501, 0.21, 0.841)
sei <- c(0.328, 0.209, 0.331, 0.27, 0.128, 0.27, 0.162, 0.128, 0.308, 0.268, 0.127, 0.322, 0.337, 0.267, 0.389, 0.21, 0.402)

REmodel_funnel <- rma(yi, sei, method="REML")
funnel(REmodel_funnel)
regtest(REmodel_funnel)
